Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Forward ¶
type Forward interface {
Run() // Run the accept loop
Stop() // Stop the accept loop
Port() vpnkit.Port // Port describes the forwards
}
Forward listens for incoming connections from the "outside" and forwards them to a remote.
type Maker ¶
type Maker struct {
TCP TCPNetwork // TCP specifies common parameters for TCP forwards
Unix UnixNetwork // Unix specifies common parameters for Unix socket or Windows named pipe forwards
}
Maker Makes Forward instances.
type TCPNetwork ¶
type TCPNetwork struct{}
TCPNetwork specifies common parameters for TCP-based port forwards.
type UnixNetwork ¶
type UnixNetwork struct{}
UnixNetwork specifies common parameters for Unix domain socket forwards.
Click to show internal directories.
Click to hide internal directories.